@@ -15,7 +15,7 @@ from noc.lib.url import URL
 from noc.lib.fileutils import rewrite_when_differ,read_file,is_differ,in_dir
 from noc.lib.validators import is_int
 from noc.cm.vcs import vcs_registry
-import os,datetime,stat,logging,random
+import os,datetime,stat,logging,random,types
 from noc.sa.models import Activator,AdministrativeDomain,ObjectGroup,ManagedObject
 from noc.main.menu import Menu
 from noc.sa.protocols.sae_pb2 import *
@@ -241,6 +241,14 @@ class Object(models.Model):
                     text=text,
                     relevancy=1.0, # No weighted search yes
                     )
+    ##
+    ##
+    ##
+    def pull_now_link(self):
+        return "<A HREF='/cm/%s/%d/now/'>Get Now</A>"%(self.repo_name,self.id)
+    pull_now_link.short_description="Get Now"
+    pull_now_link.allow_tags=True
+
 ##
 ## Config
 ##
@@ -268,7 +276,7 @@ class Config(Object):
                 timeout+=random.randint(-timeout/variation,timeout/variation) # Add jitter to avoid blocking by dead task
                 self.next_pull=datetime.datetime.now()+datetime.timedelta(seconds=timeout)
                 self.save()
-                return            
+                return
             if self.pull_every:
                 self.next_pull=datetime.datetime.now()+datetime.timedelta(seconds=self.pull_every)
                 self.save()
@@ -322,6 +330,16 @@ class Config(Object):
         q&=(Q(administrative_domain__isnull=True)|Q(administrative_domain=self.managed_object.administrative_domain))
         q&=(Q(group__isnull=True)|Q(group__in=self.managed_object.groups.all))
         return set([n.notification_group for n in ObjectNotify.objects.filter(q)])
+
+    def write(self,data):
+        if type(data)==types.ListType:
+            # Convert list to plain text
+            r=[]
+            for d in sorted(data,lambda x,y:cmp(x["name"],y["name"])):
+                r+=["==[ %s ]========================================\n%s"%(d["name"],d["config"])]
+            data="\n".join(r)
+        super(Config,self).write(data)
+
 ##
 ## PrefixList
 ##
@@ -331,13 +349,29 @@ class PrefixList(Object):
         verbose_name_plural="Prefix Lists"
     repo_name="prefix-list"
     @classmethod
+    def build_prefix_lists(cls):
+        from noc.peer.resolver import resolve_as_set_prefixes
+        from noc.peer.tree import optimize_prefix_list
+        from noc.peer.models import PeeringPoint
+        result=[]
+        for pp in PeeringPoint.objects.all():
+            profile=pp.profile
+            for name,filter_exp in pp.generated_prefix_lists:
+                prefixes=resolve_as_set_prefixes(filter_exp)
+                strict=len(prefixes)<10
+                if not strict:
+                    prefixes=optimize_prefix_list(prefixes)
+                prefixes=sorted(prefixes)
+                pl=profile.generate_prefix_list(name,prefixes,strict)
+                result+=[(pp,name,pl)]
+        return result
+    @classmethod
     def global_pull(cls):
-        from noc.peer.builder import build_prefix_lists
         objects={}
         for o in PrefixList.objects.all():
             objects[o.repo_path]=o
         logging.debug("PrefixList.global_pull(): building prefix lists")
-        for peering_point,pl_name,pl in build_prefix_lists():
+        for peering_point,pl_name,pl in PrefixList.build_prefix_lists():
             logging.debug("PrefixList.global_pull(): writing %s/%s (%d lines)"%(peering_point.hostname,pl_name,len(pl.split("\n"))))
             path=os.path.join(peering_point.hostname,pl_name)
             if path in objects:
