@@ -9,7 +9,7 @@
 """
 from django.conf.urls.defaults import *
 from django.contrib.auth.decorators import login_required
-from noc.cm.views import view,diff
+from noc.cm.views import view,diff,pull_now
 
 urlpatterns = patterns ( "",
     (r"^view/(?P<repo>[^/]+)/(?P<object_id>\d+)/$", login_required(view)),
@@ -18,4 +18,5 @@ urlpatterns = patterns ( "",
     (r"^view/(?P<repo>[^/]+)/(?P<object_id>\d+)/(?P<revision>\d+)/text/$", login_required(view), {"format":"text"}),
     (r"^view/(?P<repo>[^/]+)/(?P<object_id>\d+)/diff/$", login_required(diff)),
     (r"^view/(?P<repo>[^/]+)/(?P<object_id>\d+)/diff/(?P<mode>[u2])/(?P<r1>.+)/(?P<r2>.+)/$", login_required(diff)),
+    (r"(?P<repo>[^/]+)/(?P<object_id>\d+)/now/", login_required(pull_now)),
 )
