@@ -11,8 +11,8 @@
 from django.shortcuts import get_object_or_404
 from django.http import HttpResponse,HttpResponseRedirect,HttpResponseForbidden
 from django import forms
-
 from noc.ip.models import VRFGroup,VRF,IPv4BlockAccess,IPv4Block,IPv4Address,IPv4AddressRange
+from noc.vc.models import VC
 from noc.peer.models import AS
 from noc.lib.render import render,render_success,render_failure
 from noc.lib.validators import is_rd,is_cidr,is_int,is_ipv4,is_fqdn
@@ -45,7 +45,6 @@ def vrf_index(request,vrf_id,prefix="0.0.0.0/0"):
     total=prefix.size
     block_info=[
         ("Net",         prefix.prefix),
-        ("Maintainers", ", ".join([str(u) for u in prefix.maintainers])),
         ("Netmask",     prefix.netmask),
         ("Broadcast",   prefix.broadcast),
         ("Wildcard",    prefix.wildcard),
@@ -116,6 +115,7 @@ def allocate_block(request,vrf_id,prefix=None):
     suggestions=[]
     parent=prefix
     block_id=None
+    initial={}
     if prefix:
         assert is_cidr(prefix)
         block=get_object_or_404(IPv4Block,vrf=vrf,prefix=prefix)
@@ -130,7 +130,7 @@ def allocate_block(request,vrf_id,prefix=None):
     else:
         match=rx_referer_prefix.match(request.META.get("HTTP_REFERER",""))
         if match and is_cidr(match.group(1)):
-            # Suggest blocks
+            # Suggest blocks of different sizes
             parent=match.group(1)
             free=[(x.split("/")[0],int(x.split("/")[1])) for x in free_blocks(parent,[p.prefix for p in vrf.prefixes(top=parent)])]
             free=sorted(free,lambda x,y: -cmp(x[1],y[1]))
@@ -139,7 +139,11 @@ def allocate_block(request,vrf_id,prefix=None):
                     if fm<=m:
                         suggestions+=["%s/%d"%(fp,m)]
                         break
-        initial={}
+            # Fill initial prefix
+            prefix=parent.split("/")[0]
+            while prefix.endswith(".0"):
+                prefix=prefix[:-2]
+            initial["prefix"]=prefix
         p=""
     if request.POST:
         form=AllocateBlockForm(request.POST,vrf=vrf,block_id=block_id)
@@ -431,3 +435,24 @@ def upload_axfr(request,vrf_id,prefix):
             count=upload_axfr(data.split("\n"))
             return render_success(request,"Zone transfered","%d IP addresses updated"%count)
     return HttpResponseRedirect("/ip/%d/%s/tools/"%(vrf_id,prefix))
+##
+## Bind VC to Prefix
+##
+class BindVCForm(forms.Form):
+    vc=forms.ModelChoiceField(label="VC",queryset=VC.objects.all(),required=True)
+    
+def bind_vc(request,vrf_id,prefix):
+    vrf=get_object_or_404(VRF,id=int(vrf_id))
+    p=get_object_or_404(IPv4Block,vrf=vrf,prefix=prefix)
+    if not IPv4BlockAccess.check_write_access(request.user,vrf,prefix):
+        return HttpResponseForbidden("Permission denied")
+    initial={"vc":p.vc}
+    if request.POST:
+        form=BindVCForm(request.POST,initial=initial)
+        if form.is_valid():
+            p.vc=form.cleaned_data["vc"]
+            p.save()
+            return HttpResponseRedirect("/ip/%d/%s/"%(vrf.id,prefix))
+    else:
+        form=BindVCForm(initial=initial)
+    return render(request,"ip/bind_vc.html",{"form":form,"prefix":p})
