@@ -71,6 +71,9 @@ class NoMemoryError(SocketError):
 class BadFileError(SocketError):
     message="Bad File Descriptor"
 
+class AddressInUse(SocketError):
+    message="Address already in use"
+
 ##
 ## Error name to Exception class mapping
 ## Used to populate SOCKET_ERROR_TO_EXCEP
@@ -86,6 +89,7 @@ SOCKET_ERRORS=[
     ("EPIPE",           BrokenPipeError),
     ("EACCES",          AccessError),
     ("EBADF",           BadFileError),
+    ("EADDRINUSE",      AddressInUse),
 ]
 
 SOCKET_GAIERROR=[
@@ -268,6 +272,8 @@ class ListenTCPSocket(Socket):
         self.kwargs=kwargs
     
     def create_socket(self):
+        if self.socket: # Called twice
+            return
         self.socket=socket.socket(socket.AF_INET,socket.SOCK_STREAM)
         self.socket.setsockopt(socket.SOL_SOCKET,socket.SO_REUSEADDR,
             self.socket.getsockopt(socket.SOL_SOCKET,socket.SO_REUSEADDR) | 1)
