@@ -7,8 +7,9 @@
 """
 from noc.lib.render import render
 from noc.lib.registry import Registry
-from noc.lib.svg import has_svg_support,vertical_text_inline
 from django.conf import settings
+from django.http import HttpResponse
+import cStringIO,csv
 
 #
 admin_media_prefix=settings.ADMIN_MEDIA_PREFIX
@@ -28,11 +29,12 @@ report_registry=ReportRegistry()
 ## 'format' is a function accepting value and returning valid html code
 ##
 class Column(object):
-    def __init__(self,name,align=None,v_align=None,format=None,summary=None):
+    def __init__(self,name,align=None,v_align=None,format=None,csv_format=None,summary=None):
         self.name=name
         self.align=align
         self.v_align=v_align
         self.format=format
+        self.csv_format=csv_format
         if summary:
             self.summary=AGGREGATE_FUNCTIONS[summary]
         else:
@@ -40,7 +42,7 @@ class Column(object):
         
     def render_header(self):
         return "<TH>%s</TH>"%self.name
-        
+    
     def render_cell(self,value,bold=False):
         if value is None:
             value=""
@@ -59,6 +61,16 @@ class Column(object):
             return "<TD%s><B>%s</B></TD>"%(flags,value)
         else:
             return "<TD%s>%s</TD>"%(flags,value)
+    
+    def render_csv_header(self):
+        return self.name
+    
+    def render_csv_cell(self,value,bold=False):
+        if value is None:
+            return ""
+        if self.csv_format:
+            value=self.csv_format(value)
+        return unicode(value).encode("utf-8")
 ##
 ## Boolean field rendered as checkmark
 ##
@@ -121,9 +133,10 @@ class Report(object):
     columns=[]
     refresh=None # Time to refresh report (in seconds)
     
-    def __init__(self,request,query=None):
+    def __init__(self,request,query=None,format=None):
         self.request=request
         self.query=query
+        self.format=format if format is not None else "html"
         if self.form_class:
             if self.query:
                 self.form=self.form_class(query)
@@ -146,9 +159,9 @@ class Report(object):
     def is_valid(self):
         return self.form is None or self.form.is_valid()
     
-    def render(self):
+    def render_html(self):
         out="<TABLE SUMMARY='%s'>"%self.title
-        out+="<TR>"+"".join([c.render_header() for c in self.columns])+"</TR>"
+        out+="<THEAD><TR>"+"".join([c.render_header() for c in self.columns])+"</TR></THEAD>"
         n=0
         for row in self.get_queryset():
             out+="<TR CLASS='row%d'>"%((n%2)+1)+"".join([c.render_cell(v) for c,v in zip(self.columns,row)])+"</TR>"
@@ -166,8 +179,22 @@ class Report(object):
                     out+="<TD></TD>"
             out+="</TR>"
         out+="</TABLE>"
+        out+="<A HREF='?format=csv'><B>CSV Report</B></A>"
         return render(self.request,self.template,{"report":self,"query":self.query,"data":out,"refresh":self.refresh})
-            
+    
+    def render_csv(self):
+        out=cStringIO.StringIO()
+        writer=csv.writer(out)
+        writer.writerow([c.render_csv_header() for c in self.columns])
+        for row in self.get_queryset():
+            writer.writerow([c.render_csv_cell(v) for c,v in zip(self.columns,row)])
+        return HttpResponse(out.getvalue(),mimetype="text/csv")
+    
+    def render(self):
+        if self.format=="csv":
+            return self.render_csv()
+        return self.render_html()
+        
     def get_queryset(self):
         return []
         
@@ -180,25 +207,17 @@ class Report(object):
 ## get_queryset must return a triple of (column-label,row-label,value)
 class MatrixReport(Report):
     def render(self):
-        def column_label_svg(s):
-            return vertical_text_inline(s)
-        def column_label_html(s):
-            return "<BR/>".join(s)
-        if has_svg_support(self.request):
-            column_label=column_label_svg
-        else:
-            column_label=column_label_html
         data={}
-        cl={}
-        rl={}
+        cl=set()
+        rl=set()
         for c,r,v in self.get_queryset():
             data[c,r]=v
-            cl[c]=None
-            rl[r]=None
-        cl=sorted(cl.keys())
-        rl=sorted(rl.keys())
+            cl.add(c)
+            rl.add(r)
+        cl=sorted(cl)
+        rl=sorted(rl)
         out="<TABLE SUMMARY='%s' BORDER='1'>"%self.title
-        out+="<TR><TH></TH>%s</TR>"%"".join(["<TH>%s</TH>"%column_label(c) for c in cl])
+        out+="<TR><TH></TH>%s</TR>"%"".join(["<TH><DIV CLASS='vtext'>%s</DIV></TH>"%c for c in cl])
         n=0
         for r in rl:
             out+="<TR CLASS='row%d'><TD><B>%s</B></TD>"%((n%2)+1,r)
