@@ -12,17 +12,17 @@ from __future__ import with_statement
 import django.contrib.auth
 from django.shortcuts import get_object_or_404
 from django.http import HttpResponseRedirect,HttpResponseNotFound,HttpResponseForbidden,HttpResponse
+from django.db.models.loading import get_model
 from django.core.cache import cache
 from django.utils.cache import patch_response_headers
 from django import forms
 from django.views.generic import list_detail
 from noc.lib.render import render,render_success,render_failure,render_json
-from noc.lib.svg import vertical_text_svg
 from noc.main.report import report_registry
 from noc.main.menu import MENU
 from noc.main.search import search as search_engine
 from noc.main.models import RefBook, RefBookData, TimePattern
-import os, types, ConfigParser, pwd, re, time, datetime
+import os, types, ConfigParser, pwd, re, time, datetime, csv
 
 ##
 ## Startup boilerplate
@@ -80,7 +80,8 @@ def report(request,report):
         rc=report_registry[report]
     except KeyError:
         return HttpResponseNotFound("No report found")
-    report=rc(request,request.POST)
+    format=request.GET.get("format","html")
+    report=rc(request,request.POST,format=format)
     if report.is_valid():
         return report.render()
     else:
@@ -317,7 +318,6 @@ def refbook_new(request,refbook_id):
         rbr.save()
         return HttpResponseRedirect("/main/refbook/%d/%d/"%(rb.id,rbr.id))
     return render(request,"main/refbook_new.html",{"rb":rb})
-
 ##
 ## Delete refbook record
 ##
@@ -330,15 +330,6 @@ def refbook_delete(request,refbook_id,record_id):
     rbd.delete()
     return HttpResponseRedirect("/main/refbook/%d/"%rb.id)
 ##
-## Render SVG with vertical text
-##
-def svg_text_vertical(request):
-    if request.GET:
-        text=request.GET.get("text",u"")
-    else:
-        text=u""
-    return HttpResponse(vertical_text_svg(text),mimetype="image/svg+xml")
-##
 ## Test Time Pattern
 ##
 class TimePatternTestForm(forms.Form):
@@ -356,3 +347,30 @@ def time_pattern_test(request,time_pattern_id):
         s="%02d.%02d.%04d %02d:%02d:%02d"%(now.day,now.month,now.year,now.hour,now.minute,now.second)
         form=TimePatternTestForm(initial={"time":s})
     return render(request,"main/time_pattern_test.html",{"time_pattern":time_pattern,"form":form,"result":result})
+##
+## CSV Export
+##
+def csv_export_qs(qs,fields=None):
+    model=qs.model
+    response=HttpResponse(mimetype="text/csv")
+    # response["Content-Disposition"]="attachment;filename=%s.csv"%model.__name__
+    writer=csv.writer(response)
+    # Write headers
+    headers=fields if fields else [f.name for f in model._meta.fields]
+    writer.writerow(headers)
+    # Dump data
+    for obj in qs:
+        writer.writerow([unicode(getattr(obj,f)).encode("utf-8") for f in headers])
+    # Return CSV
+    return response
+
+def admin_list_csv_export(request,app_label,model_name,queryset=None,fields=None):
+    if not request.user.is_superuser:
+        return HttpResponseForbidden()
+    if not queryset:
+        model=get_model(app_label,model_name)
+        queryset=model.objects.all()
+        filters=dict([(str(k),v) for k,v in request.GET.items() if k not in ("ot","o","p","q")])
+        if filters:
+            queryset=queryset.filter(**filters)
+    return csv_export_qs(queryset, fields)
