@@ -17,6 +17,9 @@ class Profile(noc.sa.profiles.Profile):
     pattern_more="^ --More--"
     pattern_unpriveleged_prompt=r"^\S+?>"
     command_super="enable"
+    command_enter_config="configure terminal"
+    command_leave_config="exit"
+    command_save_config="copy running-config startup-config\n"
     pattern_prompt=r"^\S+?#"
     pattern_lg_as_path_list=r"^(\s+\d+(?: \d+)*),"
     pattern_lg_best_path=r"(<A HREF.+?>.+?best)"
