@@ -9,13 +9,13 @@ import noc.sa.script
 from noc.sa.interfaces import IGetMACAddressTable
 import re
 
-rx_line=re.compile(r"^\*\s+(?P<vlan_id>\d+)\s+(?P<mac>\S+)\s+(?P<type>\S+)\s+\S+\s+\S+\s+(?P<interfaces>.*)$")
+rx_line=re.compile(r"^(?:\*\s+)?(?P<vlan_id>\d+)\s+(?P<mac>\S+)\s+(?P<type>\S+)\s+\S+\s+(?:\S+\s+)?(?P<interfaces>.*)$")
 
 class Script(noc.sa.script.Script):
     name="Cisco.IOS.get_mac_address_table"
     implements=[IGetMACAddressTable]
     def execute(self,interface=None,vlan=None,mac=None):
-        cmd="show mac-address-table"
+        cmd="show mac address-table"
         if mac is not None:
             cmd+=" address %s"%self.profile.convert_mac(mac)
         if interface is not None:
