@@ -15,5 +15,8 @@ class Profile(noc.sa.profiles.Profile):
     name="HP.GbE2"
     supported_schemes=[TELNET,SSH]
     pattern_more="Press q to quit, any other key to continue"
-    pattern_prompt=r"^>> \S+# "
+    pattern_prompt=r"^>> [^#]+# "
     command_more=" "
+    command_leave_config="apply"
+    command_save_config="save\ny\n"
+    config_volatile=["^/\* Configuration dump taken"]
