@@ -14,5 +14,5 @@ class Script(noc.sa.script.Script):
     name="f5.BIGIP.get_config"
     implements=[IGetConfig]
     def execute(self):
-        config=self.cli("list")
+        config=self.cli("list all")
         return self.cleaned_config(config)
