@@ -8,7 +8,7 @@
 from noc.lib.fsm import StreamFSM
 from noc.lib.ecma48 import strip_control_sequences
 from noc.lib.registry import Registry
-from noc.lib.nbsocket import PTYSocket
+from noc.lib.nbsocket import PTYSocket,UDPSocket,SocketTimeoutError
 from noc.lib.debug import format_frames,get_traceback_frames
 from noc.sa.protocols.sae_pb2 import TELNET,SSH,HTTP
 from noc.sa.profiles import profile_registry
@@ -96,6 +96,16 @@ class ScriptBase(type):
             profile_registry["%s.%s"%(pv,pos)].scripts[sn]=m
         return m
 ##
+## Configuration context manager to use with "with" statement
+##
+class ConfigurationContextManager(object):
+    def __init__(self,script):
+        self.script=script
+    def __enter__(self):
+        self.script.enter_config()
+    def __exit__(self,exc_type, exc_val, exc_tb):
+        self.script.leave_config()
+##
 ##
 ##
 class Script(threading.Thread):
@@ -128,11 +138,12 @@ class Script(threading.Thread):
         self.debug_name="script-%s-%s"%(p,self.name)
         super(Script,self).__init__(name=self.debug_name,kwargs=kwargs)
         self.activator=activator
+        self.servers=activator.servers
         self.profile=profile
         self.cli_provider=None
         self.http=HTTPProvider(self.access_profile)
         if HAS_SNMP:
-            self.snmp=SNMPProvider(self.access_profile)
+            self.snmp=SNMPProvider(self)
         else:
             self.snmp=None
         self.status=False
@@ -141,6 +152,7 @@ class Script(threading.Thread):
         self.strip_echo=True
         self.kwargs=kwargs
         self.scripts=ScriptProxy(self)
+        self.need_to_save=False
     ##
     ## Checks script is stale and must be terminated
     ##
@@ -180,6 +192,9 @@ class Script(threading.Thread):
         self.debug("Running")
         try:
             self.result=self.serialize_result(self.guarded_run())
+            if self.parent is None and self.need_to_save and self.profile.command_save_config:
+                self.debug("Saving config")
+                self.cli(self.profile.command_save_config)
         except TimeOutError:
             self.error("Timed out")
         except:
@@ -191,6 +206,8 @@ class Script(threading.Thread):
         self.debug("Closing")
         if self.cli_provider:
             self.activator.request_call(self.cli_provider.close)
+        if self.snmp:
+            self.snmp.close()
         self.activator.on_script_exit(self)
         
     def execute(self,**kwargs):
@@ -274,6 +291,32 @@ class Script(threading.Thread):
     ##
     def cancel_script(self):
         self.to_cancel=True
+        
+    ## Returns configuration context
+    def configure(self):
+        return ConfigurationContextManager(self)
+        
+    # Enter configuration mote
+    def enter_config(self):
+        if self.profile.command_enter_config:
+            self.cli(self.profile.command_enter_config)
+    # Leave configuration mode
+    def leave_config(self):
+        if self.profile.command_leave_config:
+            self.cli(self.profile.command_leave_config)
+    # Save current config
+    def save_config(self,immediately=False):
+        if immediately:
+            if self.profile.command_save_config:
+                self.cli(self.profile.command_save_config)
+        else:
+            self.schedule_to_save()
+    #
+    def schedule_to_save(self):
+        self.need_to_save=True
+        if self.parent:
+            self.parent.schedule_to_save()
+
 ##
 ##
 ##
@@ -544,55 +587,180 @@ class HTTPProvider(object):
 ##
 ##
 ##
+class SNMPGetSocket(UDPSocket):
+    TTL=3
+    def __init__(self,provider,oid):
+        super(SNMPGetSocket,self).__init__(provider.factory)
+        self.provider=provider
+        self.oid=oid
+        self.address=self.provider.access_profile.address
+        self.got_result=False
+        self.sendto(self.get_snmp_request(),(self.address,161))
+    ##
+    ## Build full community, appending suffix when necessary
+    ##
+    def get_community(self):
+        c=self.provider.access_profile.snmp_ro
+        if self.provider.community_suffix:
+            c+=self.provider.community_suffix
+        return c
+    ##
+    ## Convert oid from string to a list of integers
+    ##
+    def oid_to_tuple(self,oid):
+        return [int(x) for x in oid.split(".")]
+    ##
+    ## Returns string containing SNMP GET requests to self.oids
+    ##
+    def get_snmp_request(self):
+        self.provider.script.debug("%s SNMP GET %s"%(self.address,self.oid))
+        p_mod=api.protoModules[api.protoVersion2c]
+        req_PDU =  p_mod.GetRequestPDU()
+        p_mod.apiPDU.setDefaults(req_PDU)
+        p_mod.apiPDU.setVarBinds(req_PDU,[(self.oid_to_tuple(self.oid),p_mod.Null())])
+        req_msg = p_mod.Message()
+        p_mod.apiMessage.setDefaults(req_msg)
+        p_mod.apiMessage.setCommunity(req_msg, self.get_community())
+        p_mod.apiMessage.setPDU(req_msg, req_PDU)
+        self.req_PDU=req_PDU
+        return encoder.encode(req_msg)
+    ##
+    ## Read and parse reply.
+    ## Call set_data for all returned values
+    ##
+    def on_read(self,data,address,port):
+        p_mod=api.protoModules[api.protoVersion2c]
+        while data:
+            rsp_msg, data = decoder.decode(data, asn1Spec=p_mod.Message())
+            rsp_pdu = p_mod.apiMessage.getPDU(rsp_msg)
+            if p_mod.apiPDU.getRequestID(self.req_PDU)==p_mod.apiPDU.getRequestID(rsp_pdu):
+                errorStatus = p_mod.apiPDU.getErrorStatus(rsp_pdu)
+                if errorStatus:
+                    self.provider.script.error("%s SNMP GET ERROR: %s"%(self.address,errorStatus.prettyPrint()))
+                    break
+                else:
+                    for oid, val in p_mod.apiPDU.getVarBinds(rsp_pdu):
+                        self.provider.script.debug('%s SNMP GET REPLY: %s %s'%(self.address,oid.prettyPrint(),val.prettyPrint()))
+                        self.got_result=True
+                        self.provider.queue.put(str(val))
+                        break
+        self.close()
+    ##
+    ##
+    ##
+    def on_close(self):
+        if not self.got_result:
+            self.provider.script.debug("SNMP Timeout")
+            self.provider.queue.put(None)
+        super(SNMPGetSocket,self).on_close()
+##
+##
+##
+class SNMPGetNextSocket(SNMPGetSocket):
+    TTL=5
+    ##
+    ## Returns string containing SNMP GET requests to self.oids
+    ##
+    def get_snmp_request(self):
+        self.provider.script.debug("%s SNMP GETNEXT %s"%(self.address,str(self.oid)))
+        p_mod=api.protoModules[api.protoVersion2c]
+        req_PDU =  p_mod.GetNextRequestPDU()
+        p_mod.apiPDU.setDefaults(req_PDU)
+        p_mod.apiPDU.setVarBinds(req_PDU,[(p_mod.ObjectIdentifier(self.oid_to_tuple(self.oid)),p_mod.Null())])
+        req_msg = p_mod.Message()
+        p_mod.apiMessage.setDefaults(req_msg)
+        p_mod.apiMessage.setCommunity(req_msg, self.get_community())
+        p_mod.apiMessage.setPDU(req_msg, req_PDU)
+        self.req_PDU=req_PDU
+        self.req_msg=req_msg
+        return encoder.encode(req_msg)
+
+    def on_read(self,data,address,port):
+        p_mod=api.protoModules[api.protoVersion2c]
+        while data:
+            rsp_msg, data = decoder.decode(data, asn1Spec=p_mod.Message())
+            rsp_pdu = p_mod.apiMessage.getPDU(rsp_msg)
+            # Match response to request
+            if p_mod.apiPDU.getRequestID(self.req_PDU)==p_mod.apiPDU.getRequestID(rsp_pdu):
+                # Check for SNMP errors reported
+                errorStatus = p_mod.apiPDU.getErrorStatus(rsp_pdu)
+                if errorStatus and errorStatus != 2:
+                    raise errorStatus
+                # Format var-binds table
+                var_bind_table = p_mod.apiPDU.getVarBindTable(self.req_PDU, rsp_pdu)
+                # Report SNMP table
+                for table_row in var_bind_table:
+                    for name, val in table_row:
+                        if val is None:
+                            continue
+                        oid=name.prettyPrint()
+                        if not oid.startswith(self.oid):
+                            self.close()
+                            return
+                        self.provider.script.debug('%s SNMP GETNEXT REPLY: %s %s'%(self.address,oid,str(val)))
+                        self.provider.queue.put((oid,str(val)))
+                        self.got_result=True
+                # Stop on EOM
+                for oid, val in var_bind_table[-1]:
+                    if val is not None:
+                        break
+                    else:
+                        self.close()
+                        return
+                # Generate request for next row
+                p_mod.apiPDU.setVarBinds(self.req_PDU, map(lambda (x,y),n=p_mod.Null(): (x,n), var_bind_table[-1]))
+                p_mod.apiPDU.setRequestID(self.req_PDU, p_mod.getNextRequestID())
+                self.sendto(encoder.encode(self.req_msg),(self.address,161))
+##
+##
+##
 class SNMPProvider(object):
-    TimeOutError=TimeOutError
-    def __init__(self,access_profile):
-        self.access_profile=access_profile
-        self.queue=Queue.Queue()
+    TimeOutError=SocketTimeoutError
+    def __init__(self,script):
+        self.script=script
+        self.access_profile=self.script.access_profile
+        self.factory=script.activator.factory
+        self.queue=Queue.Queue(maxsize=1)
+        self.getnext_socket=None
+        self.community_suffix=None
     
-    def str_to_oid(self,s):
-        return tuple([int(x) for x in s.split(".")])
-        
-    def get(self,oid):
-        self.run_get(oid)
-        return self.queue.get(block=True)
-    
-    def run_get(self,oid):
-        logging.debug("SNMP GET %s"%oid)
-        # Protocol version to use
-        protocol = api.protoModules[api.protoVersion1]
-        # Build PDU
-        req_pdu =  protocol.GetRequestPDU()
-        protocol.apiPDU.setDefaults(req_pdu)
-        protocol.apiPDU.setVarBinds(req_pdu, ((self.str_to_oid(oid), protocol.Null()),))
-        # Build message
-        req = protocol.Message()
-        protocol.apiMessage.setDefaults(req)
-        protocol.apiMessage.setCommunity(req, self.access_profile.snmp_ro)
-        protocol.apiMessage.setPDU(req, req_pdu)
-        def timer_callback(timeNow, start_time=time.time()):
-            if timeNow - start_time > 3:
-                raise TimeOutError
-        def recv_callback(transportDispatcher, transportDomain, transportAddress, msg, req_pdu=req_pdu):
-            while msg:
-                rsp_msg, msg = decoder.decode(msg, asn1Spec=protocol.Message())
-                rspPDU = protocol.apiMessage.getPDU(rsp_msg)
-                # Match response to request
-                if protocol.apiPDU.getRequestID(req_pdu)==protocol.apiPDU.getRequestID(rspPDU):
-                    # Check for SNMP errors reported
-                    errorStatus = protocol.apiPDU.getErrorStatus(rspPDU)
-                    #if errorStatus:
-                    #    print errorStatus.prettyPrint()
-                    #else:
-                    for oid, val in protocol.apiPDU.getVarBinds(rspPDU):
-                        self.queue.put(str(val))
-                    transportDispatcher.jobFinished(1)
-            return msg
-        transportDispatcher = AsynsockDispatcher()
-        transportDispatcher.registerTransport(udp.domainName, udp.UdpSocketTransport().openClientMode())
-        transportDispatcher.registerRecvCbFun(recv_callback)
-        transportDispatcher.registerTimerCbFun(timer_callback)
-        transportDispatcher.sendMessage(encoder.encode(req), udp.domainName, (self.access_profile.address, 161))
-        transportDispatcher.jobStarted(1)
-        transportDispatcher.runDispatcher()
-        transportDispatcher.closeDispatcher()
+    def get(self,oid,community_suffix=None):
+        self.community_suffix=community_suffix
+        s=SNMPGetSocket(self,oid)
+        try:
+            r=self.queue.get(block=True)
+            if r is None:
+                raise self.TimeOutError()
+        finally:
+            s.close()
+        return r
+    ##
+    ## getnext generator.
+    ## USAGE:
+    ## for oid,v in self.getnext("xxxxx"):
+    ##      ....
+    ##
+    def getnext(self,oid,community_suffix=None):
+        self.community_suffix=community_suffix
+        if self.getnext_socket:
+            self.getnext_socket.close()
+        self.getnext_socket=SNMPGetNextSocket(self,oid)
+        # Flush queue
+        while not self.queue.empty():
+            self.queue.get()
+        while True:
+            r=self.queue.get(block=True)
+            if r is None:
+                if self.getnext_socket.got_result: # Stop Iteration in case of success
+                    raise StopIteration
+                else: # Socket closed by Timeout
+                    raise self.TimeOutError()
+            else:
+                yield r
+    ##
+    ## Close all UDP sockets
+    ##
+    def close(self):
+        if self.getnext_socket:
+            self.getnext_socket.close()
+            del self.getnext_socket
