@@ -9,7 +9,7 @@
 """
 from django.conf.urls.defaults import *
 from django.contrib.auth.decorators import login_required
-from noc.sa.views import object_scripts,object_script,tools,upload_managed_objects,test_selector,mr_task,mr_task_result
+from noc.sa.views import object_scripts,object_script,tools,upload_managed_objects,test_selector,mr_task,mr_task_result,run_now
 
 urlpatterns = patterns ( "",
     (r"^(?P<object_id>\d+)/scripts/$",  login_required(object_scripts)),
@@ -19,4 +19,5 @@ urlpatterns = patterns ( "",
     (r"^test_selector/(?P<selector_id>\d+)", login_required(test_selector)),
     (r"^mr_task/$",                     login_required(mr_task)),
     (r"^mr_task/(?P<task_id>\d+)/$",    login_required(mr_task_result)),
+    (r"^task/(?P<task_id>\d+)/now/",    login_required(run_now)),
 )
