@@ -138,11 +138,18 @@ class VC(models.Model):
     description=models.CharField("Description",max_length=256,null=True,blank=True)
 
     def __unicode__(self):
-        s=u"%s %s %d"%(self.vc_domain,self.name,self.l1)
+        s=u"%s: %s: %d"%(self.vc_domain,self.name,self.l1)
         if self.l2:
             s+=u"/%d"%self.l2
         return s
     ##
+    ##
+    ##
+    def blocks_list(self):
+        return ", ".join([p.prefix for p in self.ipv4block_set.order_by("prefix")])
+    blocks_list.short_description="Blocks"
+    blocks_list.allow_tags=False
+    ##
     ## Enforce additional checks
     ##
     def save(self):
